==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescription } from "./SelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
                SelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemsChangedEventArgsDescriptionMetadata.c(SelectedItemsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(SelectedItemsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldItems", "Collection:object:ObjectCollection:Object");
            a.item("NewItems", "Collection:object:ObjectCollection:Object");
            a.item("CurrentItems", "Collection:object:ObjectCollection:Object");
        }
        static d(a) {
            SelectedItemsChangedEventArgsDescriptionMetadata.b(a);
            a.aa("SelectedItemsChangedEventArgs", () => new SelectedItemsChangedEventArgsDescription());
            a.z("SelectedItemsChangedEventArgs", SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedItemsChangedEventArgsDescriptionMetadata, 'SelectedItemsChangedEventArgsDescriptionMetadata');
    SelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SelectedItemsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedItemsChangedEventArgsDescription } from "./SelectedItemsChangedEventArgsDescription";
/**
 * @hidden
 */
export let SelectedItemsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class SelectedItemsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (SelectedItemsChangedEventArgsDescriptionMetadata.a == null) {
                SelectedItemsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SelectedItemsChangedEventArgsDescriptionMetadata.c(SelectedItemsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(SelectedItemsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("OldItems", "Collection:object:ObjectCollection:Object");
            a.item("NewItems", "Collection:object:ObjectCollection:Object");
            a.item("CurrentItems", "Collection:object:ObjectCollection:Object");
        }
        static d(a) {
            SelectedItemsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("SelectedItemsChangedEventArgs", () => new SelectedItemsChangedEventArgsDescription());
            a.ab("SelectedItemsChangedEventArgs", SelectedItemsChangedEventArgsDescriptionMetadata.a);
        }
    }
    SelectedItemsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(SelectedItemsChangedEventArgsDescriptionMetadata, 'SelectedItemsChangedEventArgsDescriptionMetadata');
    SelectedItemsChangedEventArgsDescriptionMetadata.a = null;
    return SelectedItemsChangedEventArgsDescriptionMetadata;
})();
